@@ -22,3 +22,21 @@ before 'run' => sub {
 
 1;
 
+=head1 NAME
+
+Gitalist::ScriptRole - Role for Gitalist scripts.
+
+=head1 DESCRIPTION
+
+Wraps the run method in Catalyst scripts to apply the C<< --repo_dir >>
+option.
+
+=head1 AUTHORS
+
+See L<Gitalist> for authors.
+
+=head1 LICENSE
+
+See L<Gitalist> for the license.
+
+=cut
