@@ -1,4 +1,11 @@
 #!/usr/bin/env perl
+use FindBin;
+BEGIN {
+    my $env = "$FindBin::Bin/script/env";
+    if (-r $env) {
+        do $env or die $@;
+    }
+}
 
 BEGIN {
     $ENV{CATALYST_SCRIPT_GEN} = 40;
