@@ -1,4 +1,11 @@
 #!/usr/bin/env perl
+use FindBin;
+BEGIN {
+    my $env = "$FindBin::Bin/script/env";
+    if (-r $env) {
+        do $env or die $@;
+    }
+}
 
 use Catalyst::ScriptRunner;
 Catalyst::ScriptRunner->run('Gitalist','Test');
